import { Component, OnInit, Input, EventEmitter, ChangeDetectionStrategy, HostListener, Output } from '@angular/core';
import { ActionItem } from './action-item.model';

@Component({
  selector: 're-action-button',
  template: "\n    <div class=\"btn-group {{'drop' + direction }}\" [ngClass]=\"{open: isOpen}\">\n      <button class=\"btn btn-{{type}}\" (click)=\"toggle($event)\" [disabled]=\"disabled\">\n        {{buttonText}}\n      </button>\n      <button type=\"button\" class=\"btn btn-{{type}} dropdown-toggle\" aria-haspopup=\"true\" [attr.aria-expanded]=\"true\"\n              (click)=\"toggle($event)\" [disabled]=\"disabled\">\n        <span class=\"caret\"></span>\n        <span class=\"sr-only\">Split button!</span>\n      </button>\n\n      <ul class=\"dropdown-menu\" role=\"menu\">\n        <ng-container *ngFor=\"let item of actions\">\n          <li *ngIf=\"!item.divider\" role=\"menuitem\" (click)=\"onActionClick(item)\"><a>{{item.text}}</a></li>\n          <li *ngIf=\"item.divider\" class=\"divider\"></li>\n        </ng-container>\n      </ul>\n    </div>\n  ",
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class ActionButtonComponent {
  @Input() type: 'default'|'primary'| 'success' | 'info' | 'warning' | 'danger' = 'primary';
  @Input() direction: 'down'| 'up' = 'down';
  @Input() buttonText: string;
  @Input() isOpen = false;
  @Input() actions: ActionItem[];
  @Input() disabled = false;
  @Output() actionClick = new EventEmitter<ActionItem>();
  @Output() openStatusChange = new EventEmitter<boolean>();

  toggle($event?: MouseEvent) {
    if ($event) {
      $event.stopPropagation();
    }
    this.isOpen = !this.isOpen;
    this.openStatusChange.emit(this.isOpen);
  }

  @HostListener('document:click', ['$event'])
  close($event?: MouseEvent) {
    this.isOpen = false;
    this.openStatusChange.emit(this.isOpen);
  }

  onActionClick(item: ActionItem) {
    this.close();
    this.actionClick.emit(item);
  }
}
