import { Component, Input, Output, EventEmitter, ChangeDetectionStrategy } from '@angular/core';
import { RebirthUIConfig } from '../rebirth-ui.config';

@Component({
  selector: 're-alert-box',
  template: "\n    <div class=\"alert alert-{{type}}\" [ngClass]=\"{'alert-dismissible': closable}\" role=\"alert\">\n      <button type=\"button\" class=\"close\" data-dismiss=\"alert\" aria-label=\"Close\" *ngIf=\"closable\" (click)=\"closeBox()\">\n        <span aria-hidden=\"true\">&times;</span>\n      </button>\n      <ng-content></ng-content>\n    </div>\n  ",
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class AlertBoxComponent {
  @Input() type: 'success' | 'info' | 'warning' | 'danger';
  @Input() closable: boolean;
  @Output() close = new EventEmitter<any>();

  constructor(private rebirthUIConfig: RebirthUIConfig) {
    this.type = <any>rebirthUIConfig.alertBox.type;
    this.closable = rebirthUIConfig.alertBox.closable;
  }

  @Input()
  set disappearTime(time) {
    if (time) {
      setTimeout(() => this.onCloseBox(), time);
    }
  }

  closeBox() {
    this.onCloseBox();
  }

  private onCloseBox() {
    this.close.emit(this);
  }
}
