import { Component, EventEmitter, ChangeDetectionStrategy } from '@angular/core';
import { Modal, ModalDismissReasons } from '../modal';
import { DialogOptions } from './dialog-options.model';
import { RebirthUIConfig } from '../rebirth-ui.config';

@Component({
  selector: 're-confirm-dialog',
  template: "\n    <div class=\"modal-header\">\n      <button type=\"button\" class=\"close\" data-dismiss=\"modal\" aria-label=\"Close\" (click)=\"no()\">\n        <span aria-hidden=\"true\">&times;</span></button>\n      <h4 class=\"modal-title\">{{context.title}}</h4>\n    </div>\n    <div class=\"modal-body\">\n      <p *ngIf=\"!context.html\">{{context.content}}</p>\n      <p *ngIf=\"context.html\" [innerHTML]=\"context.content\"></p>\n    </div>\n    <div class=\"modal-footer\">\n      <button type=\"button\" class=\"btn btn-primary\" (click)=\"yes()\">{{context.yes || btnYes}}</button>\n      <button type=\"button\" class=\"btn btn-warning\" (click)=\"no()\">{{context.no || btnNo}}</button>\n    </div>\n  ",
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class ConfirmDialogComponent implements Modal {
  context: DialogOptions;
  dismiss: EventEmitter<any>;
  btnYes: string;
  btnNo: string;

  constructor(private rebirthUIConfig: RebirthUIConfig) {
    this.btnYes = rebirthUIConfig.dialog.button.yes;
    this.btnNo = rebirthUIConfig.dialog.button.no;
  }

  yes() {
    this.dismiss.emit(ModalDismissReasons.YES);
  }

  no() {
    this.dismiss.error(ModalDismissReasons.NO);
  }

}
