import { Component, Input, ViewChild, EventEmitter, Output, ChangeDetectionStrategy, Renderer } from '@angular/core';
import { ModalOptions } from './modal-options.model';
import { ModalWindowComponent } from './modal-window.component';
import { DocumentRef } from '../window-ref';

@Component({
  selector: 're-modal',
  template: "\n    <re-modal-window [instanceCount]=\"instanceCount\" [isOpen]=\"isOpen\" role=\"dialog\"\n                     class=\"modal fade {{modalOptions.modalClass? modalOptions.modalClass : ''}}\"\n                     [ngClass]=\"{'in': isOpen}\"\n                     [ngStyle]=\"{'display': isOpen ? 'block': 'none','z-index': 1050 + instanceCount *10}\" tabindex=\"-1\">\n\n    </re-modal-window>\n    <re-modal-backdrop [instanceCount]=\"instanceCount\" [modalOptions]=\"modalOptions\" [isOpen]=\"isOpen\"\n                       *ngIf=\"modalOptions.backdrop !== false\"></re-modal-backdrop>\n  ",
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class ModalComponent {
  static MODEL_OPEN_CSS = 'modal-open';
  @Input() isOpen: boolean = false;
  @Output() dismiss = new EventEmitter<any>();
  @Input() modalOptions: ModalOptions;
  @ViewChild(ModalWindowComponent) modalWindowComponent: ModalWindowComponent;
  instanceCount = 0;

  constructor(private renderer: Renderer, private documentRef: DocumentRef) {

  }

  open() {
    this.isOpen = true;
    this.modalWindowComponent.isOpen = true;
    this.toggleBodyClass(true);
  }

  close() {
    this.isOpen = false;
  }

  cleanup() {
    this.toggleBodyClass(false);
  }

  addContent<T>(options: ModalOptions, instanceCount: number): EventEmitter<T> {
    this.modalOptions = options;
    this.instanceCount = instanceCount;
    this.modalWindowComponent.addContent(options, this.dismiss);
    return this.dismiss;
  }

  private toggleBodyClass(isAdd: boolean): void {
    this.renderer.setElementClass(this.documentRef.body, ModalComponent.MODEL_OPEN_CSS, isAdd);
  }

}
