import {
  Component,
  OnInit,
  QueryList,
  ContentChildren,
  Input,
  Output,
  EventEmitter,
  ChangeDetectionStrategy, AfterContentInit
} from '@angular/core';
import { TabComponent } from './tab.component';
import { RebirthUIConfig } from '../rebirth-ui.config';

@Component({
  selector: 're-tabs',
  template: "\n    <ul class=\"nav nav-{{type}} {{cssClass}}\" [ngClass]=\"{'nav-stacked': vertical,'nav-justified': justified}\"\n        role=\"tablist\">\n      <li role=\"presentation\" *ngFor=\"let tab of tabs\" [class.disabled]=\"tab.disabled\"\n          [class.active]=\"tab.id == activeTab\" (click)=\"select(tab.id)\">\n        <a role=\"tab\" data-toggle=\"tab\" [attr.aria-expanded]=\"tab.id == activeTab\">\n          <template *ngIf=\"!tab.title\" [ngTemplateOutlet]=\"tab.titleTpl?.templateRef\"></template>\n          <span *ngIf=\"tab.title\">{{tab.title}}</span>\n        </a>\n      </li>\n    </ul>\n    <div class=\"tab-content\">\n      <ng-container *ngFor=\"let tab of tabs\">\n        <div class=\"tab-pane fade in\" role=\"tabpanel\" *ngIf=\"tab.id == activeTab\"\n             [ngClass]=\"{'in active': tab.id == activeTab}\">\n          <template [ngTemplateOutlet]=\"tab.contentTpl.templateRef\"></template>\n        </div>\n      </ng-container>\n    </div>\n  ",
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class TabsComponent implements OnInit, AfterContentInit {
  @Input() type: 'tabs' | 'pills';
  @Input() activeTab: number |string;
  @Input() vertical: boolean;
  @Input() justified: boolean;
  @Input() cssClass: string;
  @ContentChildren(TabComponent) tabs: QueryList<TabComponent>;
  @Output() activeTabChange = new EventEmitter<number| string>();

  constructor(private rebirthUIConfig: RebirthUIConfig) {
    this.type = <any>rebirthUIConfig.tabs.type;
    this.justified = rebirthUIConfig.tabs.justified;
    this.vertical = rebirthUIConfig.tabs.vertical;
  }

  ngOnInit() {
  }

  ngAfterContentInit(): void {
    if (this.activeTab === undefined && this.tabs.length) {
      this.select(this.tabs.first.id);
    }
  }

  select(id: number | string) {
    const tab = this.tabs.find(item => item.id === id);
    if (tab && !tab.disabled) {
      this.activeTab = id;
      this.activeTabChange.emit(id);
    }
  }

}
