var gulp = require('gulp');
var os = require('os');
var path = require('path');
var sass = require('gulp-sass');
var rename = require("gulp-rename");
var inlineNg2Template = require('gulp-inline-ng2-template');
var runSequence = require('run-sequence').use(gulp);
var clean = require('gulp-clean');
var exec = require('child_process').exec;
var del = require('del');
var gulpIgnore = require('gulp-ignore');
var gulpif = require('gulp-if');

const config = {
  src: './src/app/exports',
  dest: './dist',
  lib: './lib',
  aot: './aot'
};

function platformPath(path) {
  return /^win/.test(os.platform()) ? path + '.cmd' : path;
}

gulp.task('clean:dist', function () {
  return del(config.dest, config.aot, config.lib);
});

gulp.task('copy:exports', function () {
  return gulp.src([config.src + '/**/*.*'])
    .pipe(gulpif(/.+\.scss/g, sass({outputStyle: 'compressed'}).on('error', sass.logError)))
    .pipe(rename(function (path) {
      if (path.extname === '.css') {
        path.extname = '.scss';
      }
    }))
    .pipe(gulp.dest(config.dest));
});

gulp.task('ng2:inline', function () {
  return gulp.src([config.dest + '/**/*.ts'])
    .pipe(inlineNg2Template({useRelativePaths: true, target: 'es5'}))
    .pipe(gulp.dest(config.dest + '/'));
});

gulp.task('ng2:aot', function (cb) {
  var executable = path.join(__dirname, platformPath('/node_modules/.bin/ngc'));
  exec(executable + ' -p ./dist/tsconfig-es2015.json', function (e) {
    if (e) {
      console.error(e);
    }
    // del([config.aot, config.dest]);
    cb(e);
  }).stdout.on('data', function (data) {
    console.log(data);
  });
});

gulp.task('prenpm', function () {
  return gulp.src(['README.md', 'package.json'], {read: true})
    .pipe(gulp.dest(config.lib));
});

gulp.task('prepublish', function (cb) {
  runSequence(['copy:exports', 'ng2:inline', 'ng2:aot', 'prenpm'], cb);
});
